@@ -8,7 +8,6 @@ use base qw(Test::Class);
 use Sub::Override;
 use Test::Most;
 
-#{{{ sub make_fixture
 sub make_fixture : Test(setup => 1)
 {
     my $self = shift;
@@ -21,9 +20,7 @@ sub make_fixture : Test(setup => 1)
         }
     );
 }
-#}}}
 
-#{{{ sub TEST__IS_ONE_OF
 sub TEST__IS_ONE_OF : Test(4)
 {
     is(
@@ -50,9 +47,7 @@ sub TEST__IS_ONE_OF : Test(4)
         "Doesn't find element, even if there's more than one element in the list.",
     );
 }
-#}}}
 
-#{{{ sub TEST__CHECK_PROJECT_ID
 sub TEST__CHECK_PROJECT_ID : Test(3)
 {
     is(
@@ -73,9 +68,7 @@ sub TEST__CHECK_PROJECT_ID : Test(3)
         "'a' is not a valid project id",
     );
 }
-#}}}
 
-#{{{ sub TEST__CHECK_STORY_ID
 sub TEST__CHECK_STORY_ID : Test(3)
 {
     is(
@@ -96,9 +89,7 @@ sub TEST__CHECK_STORY_ID : Test(3)
         "'a' is not a valid story id",
     );
 }
-#}}}
 
-#{{{ sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE
 sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE : Test(4)
 {
     my $self = shift;
@@ -158,9 +149,7 @@ sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE : Tes
         '$response->{story}->[0]->{labels}->{label}',
     );
 }
-#}}}
 
-#{{{ sub TEST__SANITIZE_STORY_XML
 sub TEST__SANITIZE_STORY_XML : Test(4)
 {
     my $self = shift;
@@ -262,9 +251,7 @@ sub TEST__SANITIZE_STORY_XML : Test(4)
         '$sanitized_response ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_PROJECT_DETAILS__BASE_CASE
 sub TEST_PROJECT_DETAILS__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -303,9 +290,7 @@ sub TEST_PROJECT_DETAILS__BASE_CASE : Test(3)
         "project_details response ok"
     );
 }
-#}}}
 
-#{{{ sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -340,9 +325,7 @@ sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         "project_details response ok"
     );
 }
-#}}}
 
-#{{{ sub TEST_SHOW_STORY__BASE_CASE
 sub TEST_SHOW_STORY__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -411,9 +394,7 @@ sub TEST_SHOW_STORY__BASE_CASE : Test(3)
         'show_story ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -445,9 +426,7 @@ sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         'show_story ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_ALL_STORIES__BASE_CASE
 sub TEST_ALL_STORIES__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -565,9 +544,7 @@ sub TEST_ALL_STORIES__BASE_CASE : Test(3)
         'all_stories ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -599,9 +576,7 @@ sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         'show_story ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_STORIES_FOR_FILTER__URL_ENCODES_FILTER
 sub TEST_STORIES_FOR_FILTER__URL_ENCODES_FILTER : Test(2)
 {
     my $self = shift;
@@ -625,9 +600,7 @@ sub TEST_STORIES_FOR_FILTER__URL_ENCODES_FILTER : Test(2)
 
     eq_or_diff($query_string, "projects/1/stories?filter=This%20should%20be%20URL%20%3CEncoded%3E", "stories_for_filter URL encodes filter");
 }
-#}}}
 
-#{{{ sub TEST_STORIES_FOR_FILTER__SANITIZES_STORY_XML
 sub TEST_STORIES_FOR_FILTER__SANITIZES_STORY_XML : Test(3)
 {
     my $self = shift;
@@ -746,9 +719,7 @@ sub TEST_STORIES_FOR_FILTER__SANITIZES_STORY_XML : Test(3)
         'stories_for_filter sanitized story XML ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_UPDATE_STORY__BASE_CASE
 sub TEST_UPDATE_STORY__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -819,9 +790,7 @@ sub TEST_UPDATE_STORY__BASE_CASE : Test(3)
         'show_story ok',
     );
 }
-#}}}
 
-#{{{ sub TEST_UPDATE_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_UPDATE_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -853,19 +822,12 @@ sub TEST_UPDATE_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         'update_story ok',
     );
 }
-#}}}
 
-#{{{ sub teardown
 sub teardown : Test(teardown)
 {
     my $self = shift;
 
     $self->{'override'} = undef;
 }
-#}}}
 
-1;
-
-__END__
-
-# vim: set tabstop=4 shiftwidth=4 fdm=marker:
+1;
\ No newline at end of file
